/**
 * @api {post} /3m/meeting/conf_list.do 06.查询站点的课堂
 * @apiName conf_list
 * @apiGroup classroom
 * @apiVersion 2.1.0
 * @apiDescription 查询某个站点按月的课堂记录
 *
 * @apiParam {String} siteId 站点标识
 * @apiParam {int{>2000}} year 年份
 * @apiParam {int{1-12}} month 月份
 * @apiParam {int} pageNo=1 查询第几页，如果超出实际页数，显示最后一页
 * @apiParam {int} [pageSize=20] 每页显示多少条
 * @apiParam {Long} timestamp 时间戳
 * @apiParam {String} authId MD5(key+siteId+year+month+timestamp), 其中 key 为与系统约定的加密 key
 *
 * @apiSuccess {int} errorCode
 * 0：正常 <br/>
 * 1：siteId 错误，站点不存在或已删除 <br/>
 * 2：站点未到生效日期 <br/>
 * 3: 站点过期 <br/>
 * 4：authId 错误 <br/>
 * 5：authId 不能重复使用 <br/>
 * 6：timestamp 超时 <br/>
 * 10：报文格式错误 <br/>
 * @apiSuccess {int} year  传入的参数
 * @apiSuccess {int} month  传入的参数
 * @apiSuccess {int} pageNo  传入的参数
 * @apiSuccess {int} pageSize  传入的参数
 * @apiSuccess {int} mtgCount  符合条件的总记录数
 * @apiSuccess {List} mtgList  课堂列表
 * @apiSuccess {Object} mtgList.mtgInfo  课堂对象
 * @apiSuccess {String} mtgList.mtgInfo.mtgKey  第三方的课堂标识
 * @apiSuccess {String} mtgList.mtgInfo.mtgTitle  课堂标题
 * @apiSuccess {String} mtgList.mtgInfo.hostPwd  主持人密码
 * @apiSuccess {int} mtgList.mtgInfo.status  课堂的状态： <br/>
 * 0 正在创建 <br/>
 * 1 预约状态 <br/>
 * 2 进行中 <br/>
 * 3 已取消 <br/>
 * 4 已结束 <br/>
 * @apiSuccess {String} mtgList.mtgInfo.startTime  开始时间，第一次通过接口进入活动的时间
 * @apiSuccess {String} mtgList.mtgInfo.endTime  结束时间：如果课堂状态为 0、1、2，则是预约的课堂的结束时间；如果状态为3、4，则是课堂真实的结束时间
 *
 * @apiParamExample {xml} 请求示例
 &lt;?xml version="1.0" encoding="UTF-8"?&gt;
 &lt;param&gt;
 &lt;siteId&gt;admin&lt;/siteId&gt;
 &lt;year&gt;2017&lt;/year&gt;
 &lt;month&gt;1&lt;/month&gt;
 &lt;pageNo&gt;1&lt;/pageNo&gt;
 &lt;pageSize&gt;20&lt;/pageSize&gt;
 &lt;timestamp&gt;111&lt;/timestamp&gt;
 &lt;authId&gt;111&lt;/authId&gt;
 &lt;/param&gt;
 *
 * @apiSuccessExample {xml} 返回示例
 &lt;?xml version="1.0" encoding="UTF-8"?&gt;
 &lt;result&gt;
 &lt;errorCode&gt;0&lt;/errorCode&gt;
 &lt;year&gt;2013&lt;/year&gt;
 &lt;month&gt;11&lt;/month&gt;
 &lt;pageNo&gt;6&lt;/pageNo&gt;
 &lt;pageSize&gt;30&lt;/pageSize&gt;
 &lt;mtgCount&gt;366&lt;/mtgCount&gt;
 &lt;mtgList&gt;
     &lt;mtgInfo&gt;
         &lt;mtgKey&gt;10002321&lt;/mtgKey&gt;
         &lt;mtgTitle&gt;太阳能未来发展方向调研课堂001&lt;/mtgTitle&gt;
         &lt;hostPwd&gt;123456&lt;/hostPwd&gt;
         &lt;status&gt;3&lt;/status&gt;
         &lt;startTime&gt;2013-09-10 14:02:05&lt;/startTime&gt;
         &lt;endTime&gt;2013-09-10 18:12:05&lt;/endTime&gt;
     &lt;/mtgInfo&gt;
 &lt;/mtgList&gt;
 &lt;/result&gt;
 *
 */
