/**
 * @api {post} /3m/meeting/conf_log_total.do 14.查询课堂用户进出总记录
 * @apiName conf_log_total
 * @apiGroup user
 * @apiVersion 2.1.0
 * @apiDescription 查询单个课堂用户进出课堂的记录。统计用户第一次加入课堂时间和最后一次离开时间
 *
 * @apiParam {String} siteId 站点标识
 * @apiParam {String} mtgKey 课堂的唯一标识，由第三方维护，最大长度64
 * @apiParam {Long} timestamp 时间戳
 * @apiParam {String} authId MD5(key+siteId+mtgKey+timestamp), 其中 key 为与系统约定的加密 key
 *
 * @apiParamExample {xml} 请求示例
 &lt;?xml version="1.0" encoding="UTF-8"?&gt;
 &lt;param&gt;
 &lt;siteId&gt;shanghai&lt;/siteId&gt;
 &lt;mtgKey&gt;10002321&lt;/mtgKey&gt;
 &lt;timestamp&gt;1392032123210&lt;/timestamp&gt;
 &lt;authId&gt;4297f44b13955235245b2497399d7a93&lt;/authId&gt;
 &lt;/param&gt;
 *
 * @apiSuccess {int} errorCode
 * 0：正常 <br/>
 * 1：siteId 错误，站点不存在或已删除 <br/>
 * 2：站点未到生效日期 <br/>
 * 3: 站点过期 <br/>
 * 4：authId 错误 <br/>
 * 5：authId 不能重复使用 <br/>
 * 6：timestamp 超时 <br/>
 * 7：mtgKey 不存在 <br/>
 * 10：报文格式错误 <br/>
 * @apiSuccess {String} mtgKey  传入的参数
 * @apiSuccess {int} logCount  总记录数
 * @apiSuccess {List} logList  列表
 * @apiSuccess {Object} logList.logInfo  进出信息对象
 * @apiSuccess {String} logList.logInfo.userId  用户ID
 * @apiSuccess {String} logList.logInfo.userName  用户姓名
 * @apiSuccess {int} logList.logInfo.userRole  用户角色
 * @apiSuccess {String} logList.logInfo.joinTime  进入时间
 * @apiSuccess {String} logList.logInfo.exitTime  离开时间
 *
 * @apiSuccessExample {xml} 返回示例
 &lt;?xml version=“1.0” encoding="UTF-8"?&gt;
 &lt;result&gt;
 &lt;errorCode&gt;0&lt;/errorCode&gt;
 &lt;mtgKey&gt;10002321&lt;/mtgKey&gt;
 &lt;logCount&gt;321&lt;logCount&gt;
 &lt;logList&gt;
     &lt;logInfo&gt;
         &lt;userId&gt;12000232&lt;/userId&gt;
         &lt;userName&gt;ChinaBj001&lt;/userName&gt;
         &lt;userRole&gt;3&lt;/userRole&gt;
         &lt;joinTime&gt;2013-09-11 14:02:05&lt;/joinTime&gt;
         &lt;exitTime&gt;2013-09-11 14:15:47&lt;/exitTime&gt;
     &lt;/logInfo&gt;
 &lt;/logList&gt;
 &lt;/result&gt;
 *
 */
