/**
 * @api {post} /3m/media/get_media_list.do 27.查询站点的伴音列表
 * @apiName get_media_list
 * @apiGroup doc
 * @apiVersion 2.1.0
 * @apiDescription 查询站点的伴音列表
 *
 * @apiParam {String} siteId 站点标识
 * @apiParam {Long} timestamp 时间戳
 * @apiParam {String} authId MD5(key+siteId+timestamp), 其中 key 为与系统约定的加密 key
 * @apiParam {String} beginTime 开始日期。格式：YYYY-MM-DD HH:MM:SS
 * @apiParam {String} endTime 结束日期。格式：YYYY-MM-DD HH:MM:SS
 * @apiParam {String} [name] 文档名称
 *
 * @apiParamExample {xml} 请求示例
 &lt;?xml version="1.0" encoding="UTF-8"?&gt;
 &lt;param&gt;
     &lt;siteId&gt;admin&lt;/siteId&gt;
     &lt;beginTime&gt;2017-02-01 00:00:00&lt;/beginTime&gt;
     &lt;endTime&gt;2017-02-22 00:00:00&lt;/endTime&gt;
     &lt;name&gt;&lt;/name&gt;
     &lt;timestamp&gt;1487756351064&lt;/timestamp&gt;
     &lt;authId&gt;6f584b3a816c1405107ddd657e95292b&lt;/authId&gt;
 &lt;/param&gt;
 *
 * @apiSuccess {int} errorCode
 * 0：正常 <br/>
 * 1：siteId 错误 <br/>
 * 2：站点未到生效日期 <br/>
 * 3：站点过期 <br/>
 * 4：authId 错误 <br/>
 * 5：authId 不能重复使用 <br/>
 * 6：timestamp 超时 <br/>
 * 10：报文格式错误 <br/>
 * 11：beginTime 格式错误 <br/>
 * 12：endTime 格式错误 <br/>
 * 13：endTime 在 beginTime 之前 <br/>
 * @apiSuccess {String} beginTime
 * @apiSuccess {String} endTime
 * @apiSuccess {int} mediaCount
 * @apiSuccess {Array} mediaList
 * @apiSuccess {Object} mediaList.mediaInfo
 * @apiSuccess {String} mediaList.mediaInfo.userName 上传者用户名
 * @apiSuccess {String} mediaList.mediaInfo.startTime 上传开始时间
 * @apiSuccess {String} mediaList.mediaInfo.endTime 上传结束时间
 * @apiSuccess {int} mediaList.mediaInfo.status 状态
 * 0：上传中 <br/>
 * 1：上传完毕 <br/>
 * 2：处理中 <br/>
 * 3: 发布成功 <br/>
 * 4：取消 <br/>
 * 5：删除 <br/>
 * 6：失败 <br/>
 * @apiSuccess {String} mediaList.mediaInfo.name 名称
 * @apiSuccess {String} mediaList.mediaInfo.ID id
 *
 * @apiSuccessExample {xml} 返回示例
 &lt;?xml version=“1.0” encoding="UTF-8"?&gt;
 &lt;result&gt;
     &lt;errorCode&gt;0&lt;/errorCode&gt;
     &lt;beginTime&gt;2013-12-01 00:00:00&lt;/beginTime&gt;
     &lt;endTime&gt;2013-12-31 00:00:00&lt;/endTime&gt;
     &lt;mediaCount&gt;321&lt;/mediaCount&gt;
     &lt;mediaList&gt;
         &lt;mediaInfo&gt;
             &lt;userName&gt;ChinaBj001&lt;/userName&gt;
             &lt;startTime&gt;2013-09-11 14:02:05&lt;/startTime&gt;				    
             &lt;endTime&gt;2013-09-11 14:15:47&lt;/endTime&gt;
             &lt;status&gt;0&lt;/status&gt;
             &lt;name&gt;123.mp3&lt;/name&gt;
             &lt;ID&gt;123abcd&lt;/ID&gt;
         &lt;/mediaInfo&gt;
     &lt;/mediaList &gt;
 &lt;/result&gt;
 *
 */
