/**
 * @api {post} /3m/meeting/get_record_list.do 12.查询课堂的录制列表
 * @apiName get_record_list
 * @apiGroup classroom
 * @apiVersion 2.1.0
 * @apiDescription 查询某个课堂的录制列表
 *
 * @apiParam {String} siteId 站点标识
 * @apiParam {String} mtgKey 课堂的唯一标识
 * @apiParam {int} pageNo 第几页，大于总页数时，自动设置为1
 * @apiParam {int} pgeSize=20 每页显示多少条
 * @apiParam {Long} timestamp 时间戳
 * @apiParam {String} authId MD5(key+siteId+mtgKey+timestamp)
 *
 * @apiParamExample {xml} 请求示例
 &lt;?xml version="1.0" encoding="UTF-8"?&gt;
 &lt;param&gt;
 &lt;siteId&gt;shanghai&lt;/siteId&gt;
 &lt;mtgKey&gt;10002321&lt;/mtgKey&gt;
 &lt;pageNo&gt;1&lt;/pageNo&gt;
 &lt;pageSize&gt;20&lt;/pageSize&gt;
 &lt;timestamp&gt;1392032123210&lt;/timestamp&gt;
 &lt;authId&gt;4297f44b13955235245b2497399d7a93&lt;/authId&gt;
 &lt;/param&gt;
 *
 * @apiSuccess {int} errorCode
 * 0：正常 <br/>
 * 1：siteId 错误，站点不存在或已删除 <br/>
 * 2：站点未到生效日期 <br/>
 * 3: 站点过期 <br/>
 * 4：authId 错误 <br/>
 * 6：timestamp 超时 <br/>
 * 7：mtgKey 不存在 <br/>
 * 10：报文格式错误 <br/>
 * @apiSuccess {String} mtgKey 传入的值
 * @apiSuccess {int} pageNo 传入的值
 * @apiSuccess {int} pageSize 传入的值
 * @apiSuccess {int} recordCount 总记录数
 * @apiSuccess {List} recordList 录制列表
 * @apiSuccess {Object} recordList.recordInfo 录制对象
 * @apiSuccess {String} recordList.recordInfo.userId 录制人的ID
 * @apiSuccess {String} recordList.recordInfo.userName 录制人的姓名
 * @apiSuccess {String} recordList.recordInfo.mtgTitle 课堂主题
 * @apiSuccess {String} recordList.recordInfo.startTime 录制开始时间
 * @apiSuccess {String} recordList.recordInfo.endTime 录制结束时间
 * @apiSuccess {String} recordList.recordInfo.configFile 录制文件名
 *
 * @apiSuccessExample {xml} 返回示例
 &lt;?xml version=“1.0” encoding="UTF-8"?&gt;
 &lt;result&gt;
 &lt;errorCode&gt;0&lt;/errorCode&gt;
 &lt;mtgKey&gt;10002321&lt;/mtgKey&gt;
 &lt;pageNo&gt;6&lt;/pageNo&gt;
 &lt;pageSize&gt;30&lt;/pageSize&gt;
 &lt;recordCount&gt;3&lt;recordCount &gt;
 &lt;recordList&gt;
     &lt;recordInfo&gt;
         &lt;userId&gt;12000232&lt;/userId&gt;
         &lt;userName&gt;ChinaBj001&lt;/userName&gt;
         &lt;mtgTitle&gt;shanghai&lt;/mtgTitle&gt;
         &lt;startTime&gt;2013-09-11 14:02:05&lt;/startTime
         &lt;endTime&gt;2013-09-11 14:15:47&lt;/endTime&gt;
         &lt;configFile&gt;67303217_983041_2014-11-3-9-42-44.xml&lt;/configFile&gt;
     &lt;/recordInfo&gt;
 &lt;/recordList &gt;
 &lt;/result&gt;
 *
 */
