/**
 * @api {post} /3m/meeting/get_test_site.do 19.查询试用站点信息
 * @apiName get_test_site
 * @apiGroup site
 * @apiVersion 2.1.0
 * @apiDescription 查询试用站点信息
 *
 * @apiParam {String} siteId 站点标识
 * @apiParam {Long} timestamp 时间戳
 * @apiParam {String} authId MD5(key+siteId+timestamp), 其中 key 为与系统约定的加密 key
 *
 * @apiSuccess {int} errorCode
 * 0：正常 <br/>
 * 1：站点不存在<br/>
 * 4：authId 错误 <br/>
 * 5：authId 不能重复使用 <br/>
 * 6：timestamp 超时 <br/>
 * 10：报文格式错误 <br/>
 * @apiSuccess {String} msg 错误信息
 * @apiSuccess {Object} data 详细信息
 * @apiSuccess {String} data.siteId 站点标识
 * @apiSuccess {String} data.key 站点 Key
 * @apiSuccess {String} data.startdate 生效时间
 * @apiSuccess {String} data.enddate 失效时间
 * @apiSuccess {String} data.helpsite 帮助页面
 * @apiSuccess {int} data.audioVideoInteractive 一般与会者是否参加音视频互动
 * @apiSuccess {int} data.enableRecording 是否启用录制
 * @apiSuccess {int} data.autoRecording 是否自动录制
 * @apiSuccess {String} data.siteName 站点名称
 * @apiSuccess {String} data.siteDomain 站点域名
 * @apiSuccess {int} data.maxCapacity 最大并发人数
 * @apiSuccess {Boolean} data.supportScreen 是否支持屏幕共享
 * @apiSuccess {Boolean} data.supportMedia 是否支持媒体共享
 * @apiSuccess {Boolean} data.supportRecord 是否支持录制
 * @apiSuccess {Boolean} data.recordVisible 是否显示服务器录制
 * @apiSuccess {Boolean} data.localRecordVisible 是否显示本地录制
 * @apiSuccess {Boolean} data.supportVideo 是否支持视频
 * @apiSuccess {int} data.maxAudioChannels 最大音频路数
 * @apiSuccess {int} data.maxVideoChannels 最大视频路数
 * @apiSuccess {Boolean} data.siteType 是否正式用户
 * @apiSuccess {Boolean} data.customLogo 是否自定义logo
 * @apiSuccess {Boolean} data.pptflash 是否支持动态PPT
 * @apiSuccess {Boolean} data.allowSettingResolution 是否支持切换视频分辨率
 * @apiSuccess {String} data.website 官网
 * @apiSuccess {String} data.webCopyright 站点网站的Copyright
 * @apiSuccess {String} data.flashCopyright flash课堂的Copyright
 * @apiSuccess {String} data.mobileSupport 课堂里的手机求助对象
 * @apiSuccess {String} data.creater 课堂的父站点标识
 * @apiSuccess {int} data.extendTimes 延长次数
 * @apiSuccess {int} data.siteStatus 站点状态：1 待审核，2 审核未通过，3 启用，4 信用
 *
 * @apiParamExample {xml} 请求示例
 &lt;?xml version="1.0" encoding="UTF-8"?&gt;
 &lt;param&gt;
     &lt;siteId&gt;childSite&lt;/siteId&gt;
     &lt;timestamp&gt;111&lt;/timestamp&gt;
     &lt;authId&gt;111&lt;/authId&gt;
 &lt;/param&gt;
 *
 * @apiSuccessExample {xml} 返回示例
 &lt;?xml version="1.0" encoding="UTF-8"?&gt;
 &lt;result&gt;
     &lt;errcode&gt;0&lt;/errcode&gt;
     &lt;msg&gt;操作成功&lt;/msg&gt;
     &lt;data&gt;
         &lt;siteid&gt;{siteId}&lt;/siteid&gt;
         &lt;key&gt;{siteKey}&lt;/key&gt;
         &lt;startdate&gt;2014-10-10&lt;/startdate&gt;
         &lt;enddate&gt;2025-08-20&lt;/enddate&gt;
         &lt;helpsite&gt;&lt;/helpsite&gt;
         &lt;audioVideoInteractive&gt;1&lt;/audioVideoInteractive&gt;
         &lt;enableRecording&gt;true&lt;/enableRecording&gt;
         &lt;autoRecording&gt;false&lt;/autoRecording&gt;
         &lt;siteName&gt;站点&lt;/siteName&gt;
         &lt;siteDomain&gt;www&lt;/siteDomain&gt;
         &lt;maxCapacity&gt;1000&lt;/maxCapacity&gt;
         &lt;supportScreen&gt;false&lt;/supportScreen&gt;
         &lt;supportMedia&gt;false&lt;/supportMedia&gt;
         &lt;supportRecord&gt;false&lt;/supportRecord&gt;
         &lt;recordVisible&gt;false&lt;/recordVisible&gt;
         &lt;localRecordVisible&gt;false&lt;/localRecordVisible&gt;
         &lt;supportVideo&gt;false&lt;/supportVideo&gt;
         &lt;maxAudioChannels&gt;5&lt;/maxAudioChannels&gt;
         &lt;maxVideoChannels&gt;5&lt;/maxVideoChannels&gt;
         &lt;siteType&gt;true&lt;/siteType&gt;
         &lt;customLogo&gt;false&lt;/customLogo&gt;
         &lt;pptflash&gt;false&lt;/pptflash&gt;
         &lt;allowSettingResolution&gt;false&lt;/allowSettingResolution&gt;
         &lt;website&gt;https://www.baidu.com&lt;/website&gt;
         &lt;webCopyright&gt;三芒世纪（北京）科技有限公司&lt;/webCopyright&gt;
         &lt;flashCopyright&gt;三芒世纪（北京）科技有限公司&lt;/flashCopyright&gt;
         &lt;mobileSupport&gt;18900000000&lt;/mobileSupport&gt;
         &lt;creater&gt;1&lt;/creater&gt;
         &lt;extendTimes&gt;0&lt;/extendTimes&gt;
         &lt;siteStatus&gt;1&lt;/siteStatus&gt;
     &lt;/data&gt;
 &lt;/result&gt;
 *
 */
