/**
 * @api {post} /3m/meeting/join_mtg_app.do 04.app获取课堂信息
 * @apiName joinClassApp
 * @apiGroup classroom
 * @apiVersion 2.1.0
 * @apiDescription app获取课堂信息,如果课堂不存在，先创建该课堂
 *
 * @apiParam {String} siteId 站点标识
 * @apiParam {String} mtgKey 课堂的唯一标识。最大长度 64
 * @apiParam {String} mtgTitle 课堂名称或者课堂主题，最大长度 32
 * @apiParam {String} startTime 课堂的开始时间，作为课堂开始气泡提示的参考时间。格式为：YYYY-MM-DD HH:MM:SS
 * @apiParam {String} endTime 课堂的结束时间，作为课堂结束气泡提示的参考时间。格式为：YYYY-MM-DD HH:MM:SS
 * @apiParam {int} [language=2] 客户端语言：1 英文， 2 中文
 * @apiParam {String} userName 客户端显示的姓名，最大长度 32
 * @apiParam {String} userId 英文或数字组成的字符串，最大长度 50。等于0时是匿名用户，可以允许多个用户同时存在
 * @apiParam {int} userType 用户类型： 8 普通与会者
 * @apiParam {String} hostPwd 主持人密码，密码长度 6 到 8 位，用于对普通人员申请主持人时的验证
 * @apiParam {Long} timestamp 时间戳
 * @apiParam {String} authId MD5(key+siteId+mtgKey+userID+userType+timestamp), 其中 key 为与系统约定的加密 key
 *
 * @apiSuccess {int} errorCode
 * 0：正常 <br/>
 * 1：siteId 错误，站点不存在或已删除 <br/>
 * 2：站点未到生效日期 <br/>
 * 3: 站点过期 <br/>
 * 4：课堂信息 mtgKey/mtgTitle/hostPwd 不能为空 <br/>
 * 5：用户信息 userName/userId/userType 不能为空 <br/>
 * 6：timestamp 超时 <br/>
 * 7：authId 错误 <br/>
 * 8：authId 不能重复使用 <br/>
 * 9：课堂开始或结束时间格式错误 <br/>
 * 10：报文格式错误 <br/>
 * @apiSuccess {String} url  课堂地址
 * @apiSuccess {String} param
 * @apiSuccess {String} siteId
 * @apiSuccess {String} classID 课堂 id
 * @apiSuccess {String} userName
 * @apiSuccess {String} userId
 * @apiSuccess {String} userType
 * @apiSuccess {String} nopassword 是否需要验证密码 False:不需要验证 True: 需要验证
 * @apiSuccess {String} portalIP  服务器ip
 * @apiSuccess {String} portalPort  服务器端口
 * @apiSuccess {String} md5  返回的md5
 * @apiSuccess {String} meetingNumber  学点云系统生成的课堂号
 * @apiSuccess {Long} timestamp  时间戳
 *
 * @apiParamExample {xml} 请求示例
 &lt;param&gt;
 &lt;siteId&gt;shanghai&lt;/siteId&gt;
 &lt;mtgKey&gt;100012&lt;/mtgKey&gt;
 &lt;mtgTitle&gt;shanghai&lt;/mtgTitle&gt;
 &lt;startTime&gt;2015-08-12 14:00:00&lt;/startTime&gt;
 &lt;endTime&gt;2015-08-12 14:30:00&lt;/endTime&gt;
 &lt;language&gt;1&lt;/language&gt;
 &lt;userName&gt;shanghai&lt;/userName&gt;
 &lt;userId&gt;2000012&lt;/userId&gt;
 &lt;userType&gt;8&lt;/userType&gt;
 &lt;hostPwd&gt;123456&lt;/hostPwd&gt;
 &lt;timestamp&gt;1392032123210&lt;/timestamp&gt;
 &lt;authId&gt;4297f44b13955235245b2497399d7a93&lt;/authId&gt;
 &lt;/param&gt;
 *
 * @apiSuccessExample {xml} 返回示例
 &lt;?xml version="1.0" encoding="UTF-8"?&gt;
 &lt;result&gt;
 &lt;errorCode&gt;01&lt;/errorCode&gt;
 &lt;url&gt;http://127.0.0.1:8080/LiveClass/tests/joinClass/index.jsp&lt;/url&gt;
 &lt;param&gt;
 &lt;siteId&gt;admin&lt;/siteId&gt;
 &lt;classID&gt;1419338704&lt;/classID&gt;
 &lt;userName&gt;shanghai&lt;/userName&gt;
 &lt;userId&gt;2000012&lt;/userId&gt;
 &lt;nopassword&gt;false&lt;/nopassword&gt;
 &lt;userType&gt;8&lt;/userType&gt;
 &lt;portalIP&gt;127.0.0.1&lt;/portalIP&gt;
 &lt;portalPort&gt;8080&lt;/portalPort&gt;
 &lt;md5&gt;790a9c17892e99c89d6bef2cb1b5d2e6&lt;/md5&gt;
 &lt;/param&gt;
 &lt;timestamp&gt;1447815907543&lt;/timestamp&gt;
 &lt;meetingNumber&gt;1419338704&lt;/meetingNumber&gt;
 &lt;/result&gt;
 * 获取到param下的参数传给学点云app
 */
